diff --git a/CHANGELOG b/CHANGELOG
index 4aa384b..09b0541 100644
--- a/CHANGELOG
+++ b/CHANGELOG
@@ -55,6 +55,7 @@
 - fix to quoting for exports gathered by hosts map.
 - use mount option "nosuid" for "-hosts" map unless "suid" is explicily specified.
 - second attempt fixing quoting for exports gathered by hosts map.
+- quell annoying "cannot open mount module" message.
 
 18/06/2007 autofs-5.0.2
 -----------------------
diff --git a/daemon/mount.c b/daemon/mount.c
index 59f8f44..494ede1 100644
--- a/daemon/mount.c
+++ b/daemon/mount.c
@@ -38,14 +38,21 @@ int do_mount(struct autofs_point *ap, const char *root, const char *name, int na
 	char **ngp;
 	int rv;
 
-	mod = open_mount(modstr = fstype, ERR_PREFIX);
+	/* Initially look for a mount module but don't issue an error on fail */
+	mod = open_mount(modstr = fstype, NULL);
 	if (!mod) {
 		for (ngp = not_generic; *ngp; ngp++) {
 			if (!strcmp(fstype, *ngp))
 				break;
 		}
+		/*
+		 * If there's not a known mount module use the generic module,
+		 * otherwise redo the fs mount module with error reporting
+		 */
 		if (!*ngp)
 			mod = open_mount(modstr = "generic", ERR_PREFIX);
+		else
+			mod = open_mount(modstr = fstype, ERR_PREFIX);
 		if (!mod) {
 			error(ap->logopt,
 			      "cannot find mount method for filesystem %s",
